@@ -44,7 +44,8 @@
 #define GPRS_GCONF_TX GPRS_GCONF_PATH  "/gprs_tx_bytes"
 #define GPRS_GCONF_RESET GPRS_GCONF_PATH  "/gprs_reset_time"
 
-#define _(String) dgettext("hildon-libs", String)
+#define _tran(String) dgettext("hildon-libs", String)
+#define _(String) gettext (String)
 
 #define PERSONAL_GPRS_MON_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE (obj,\
 							                         PERSONAL_TYPE_GPRS_MON,\
@@ -247,7 +248,7 @@ void personal_gprs_mon_content_create (PersonalGprsMon *self)
 		self->priv->titleImage = gtk_image_new_from_pixbuf (pixbuf);
 		g_object_unref (pixbuf);
 	}
-    self->priv->titleLabel = gtk_label_new ("Dataplan Monitor");
+    self->priv->titleLabel = gtk_label_new (_("Dataplan Monitor"));
 	hildon_helper_set_logical_font (self->priv->titleLabel, "EmpSystemFont");
 	self->priv->titleBox = gtk_hbox_new (FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (self->priv->titleBox), 0);
@@ -263,7 +264,7 @@ void personal_gprs_mon_content_create (PersonalGprsMon *self)
 		self->priv->uploadImage = gtk_image_new_from_file ("/usr/share/icons/hicolor/26x26/hildon/personal-gprs-upload.png");
 	}
 	gtk_image_set_pixel_size (GTK_IMAGE (self->priv->uploadImage), 22);
-	self->priv->uploadLabel = gtk_label_new ("Uploaded");
+	self->priv->uploadLabel = gtk_label_new (_("Uploaded"));
 	gtk_size_group_add_widget (group, self->priv->uploadLabel);
 	self->priv->uploadContent = gtk_label_new ("0.000 B");
 	gtk_label_set_markup (GTK_LABEL (self->priv->uploadContent), "0<small><sup>.000</sup></small> B");
@@ -289,7 +290,7 @@ void personal_gprs_mon_content_create (PersonalGprsMon *self)
 		self->priv->downloadImage = gtk_image_new_from_file ("/usr/share/icons/hicolor/26x26/hildon/personal-gprs-download.png");
 	}
 	gtk_image_set_pixel_size (GTK_IMAGE (self->priv->downloadImage), 22);
-	self->priv->downloadLabel = gtk_label_new ("Downloaded");
+	self->priv->downloadLabel = gtk_label_new (_("Downloaded"));
 	gtk_size_group_add_widget (group, self->priv->downloadLabel);
 	self->priv->downloadContent = gtk_label_new ("0.000 B");
 	gtk_label_set_markup (GTK_LABEL (self->priv->downloadContent), "0<small><sup>.000</sup></small> B");
@@ -321,9 +322,9 @@ void personal_gprs_mon_content_create (PersonalGprsMon *self)
 	gtk_box_pack_start (GTK_BOX (self->priv->expandedBox), expandedUploadBox, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (self->priv->expandedBox), expandedDownloadBox, FALSE, FALSE, 0);
 	
-	self->priv->resetLabel = gtk_label_new ("Last Reset");
+	self->priv->resetLabel = gtk_label_new (_("Last Reset"));
 	gtk_size_group_add_widget (group, self->priv->resetLabel);
-	self->priv->resetContent = gtk_label_new ("Could not retrieve");
+	self->priv->resetContent = gtk_label_new (_("Could not retrieve"));
 	self->priv->resetBox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (self->priv->resetBox), self->priv->resetLabel, TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (self->priv->resetBox), self->priv->resetContent, TRUE, TRUE, 0);
@@ -469,7 +470,7 @@ gboolean personal_gprs_mon_update_content (PersonalGprsMon *self)
 	gchar dateString[256];
 	g_date_strftime (dateString, 256, "%a, %d %b %Y", date);
 	if (resetTime == 0) {
-		gtk_label_set_text (GTK_LABEL (self->priv->resetContent), "Never");
+		gtk_label_set_text (GTK_LABEL (self->priv->resetContent), _("Never"));
 	} else {
 		gtk_label_set_text (GTK_LABEL (self->priv->resetContent), dateString);
 	}
@@ -492,25 +493,25 @@ gboolean personal_gprs_mon_update_content (PersonalGprsMon *self)
 void personal_gprs_mon_settings (HDHomePluginItem *hitem, PersonalGprsMon *self)
 {
 	//g_warning ("personal_gprs_mon_settings");
-	GtkWidget *dialog = gtk_dialog_new_with_buttons ("Personal Dataplan Monitor Settings",
+	GtkWidget *dialog = gtk_dialog_new_with_buttons (_("Personal Dataplan Monitor Settings"),
         NULL, 0,
-        _("wdgt_bd_save"), GTK_RESPONSE_ACCEPT, NULL);
+        _tran("wdgt_bd_save"), GTK_RESPONSE_ACCEPT, NULL);
     GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 	GtkSizeGroup *group = GTK_SIZE_GROUP (gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL));
 	
 	GtkWidget *selector = hildon_touch_selector_new_text ();
 	
-	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), "only when switching desktops");
-	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), "every 5 seconds");
-	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), "every 30 seconds");
-	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), "every 1 minute");
-	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), "every 5 minutes");
-	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), "every 10 minutes");
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("only when switching desktops"));
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("every 5 seconds"));
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("every 30 seconds"));
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("every 1 minute"));
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("every 5 minutes"));
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("every 10 minutes"));
 		
 	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, self->priv->refresh);
 	
 	GtkWidget *refreshButton = hildon_picker_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
-	hildon_button_set_title (HILDON_BUTTON (refreshButton), "Update");
+	hildon_button_set_title (HILDON_BUTTON (refreshButton), _("Update"));
 	hildon_button_add_title_size_group (HILDON_BUTTON (refreshButton), group);
 	hildon_button_set_alignment (HILDON_BUTTON (refreshButton), 0, 0.5, 0, 0);
 
@@ -518,15 +519,15 @@ void personal_gprs_mon_settings (HDHomePluginItem *hitem, PersonalGprsMon *self)
                                      HILDON_TOUCH_SELECTOR (selector));
 	gtk_container_add (GTK_CONTAINER (content_area), refreshButton);
 	
-	GtkWidget *refreshLabel = gtk_label_new ("The widget will always refresh when you press it");
-	gtk_label_set_markup (GTK_LABEL (refreshLabel), "<small>The widget will always refresh when you press it</small>");
+	GtkWidget *refreshLabel = gtk_label_new (_("The widget will always refresh when you press it"));
+	gtk_label_set_markup (GTK_LABEL (refreshLabel), _("<small>The widget will always refresh when you press it</small>"));
 	gtk_container_add (GTK_CONTAINER (content_area), refreshLabel);
 	
 	GtkWidget *hbox = gtk_hbox_new (FALSE, 0);
 	GtkWidget *binaryPrefix = hildon_gtk_radio_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, NULL);
-	gtk_button_set_label (GTK_BUTTON (binaryPrefix), "Binary prefixes (KiB)");
+	gtk_button_set_label (GTK_BUTTON (binaryPrefix), _("Binary prefixes (KiB)"));
 	GtkWidget *siPrefix = hildon_gtk_radio_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, gtk_radio_button_get_group (GTK_RADIO_BUTTON (binaryPrefix)));
-	gtk_button_set_label (GTK_BUTTON (siPrefix), "SI prefixes (kB)");
+	gtk_button_set_label (GTK_BUTTON (siPrefix), _("SI prefixes (kB)"));
 	gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (binaryPrefix), FALSE);
 	gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (siPrefix), FALSE);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (binaryPrefix), self->priv->binaryPrefix);
@@ -536,12 +537,12 @@ void personal_gprs_mon_settings (HDHomePluginItem *hitem, PersonalGprsMon *self)
 	gtk_container_add (GTK_CONTAINER (content_area), hbox);
 	
 	GtkWidget *showResetDate = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
-	gtk_button_set_label (GTK_BUTTON (showResetDate), "Display the last reset date");
+	gtk_button_set_label (GTK_BUTTON (showResetDate), _("Display the last reset date"));
 	gtk_container_add (GTK_CONTAINER (content_area), showResetDate);
 	hildon_check_button_set_active (HILDON_CHECK_BUTTON (showResetDate), self->priv->showResetDate);
 	
 	GtkWidget *compactMode = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
-	gtk_button_set_label (GTK_BUTTON (compactMode), "Use compact layout");
+	gtk_button_set_label (GTK_BUTTON (compactMode), _("Use compact layout"));
 	gtk_container_add (GTK_CONTAINER (content_area), compactMode);
 	hildon_check_button_set_active (HILDON_CHECK_BUTTON (compactMode), self->priv->compactMode);
 	
@@ -773,6 +774,10 @@ static void personal_gprs_mon_class_finalize (PersonalGprsMonClass *klass G_GNUC
 static void personal_gprs_mon_init (PersonalGprsMon *self)
 {
 	//g_warning ("personal_gprs_mon_init");
+	setlocale (LC_ALL, "");
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+	textdomain (GETTEXT_PACKAGE);
+
 	self->priv = PERSONAL_GPRS_MON_GET_PRIVATE (self);
 	self->priv->eventID = 0;
 	self->priv->isPressed = FALSE;
